@@ -4,15 +4,27 @@ import subprocess
 import textwrap
 from multiprocessing import Pool
 from sys import platform
+from time import sleep
+from random import randint
 
 from cloudmesh.common.DateTime import DateTime
 from cloudmesh.common.parameter import Parameter
 from cloudmesh.common.util import path_expand
 from cloudmesh.common.util import readfile
-
+from pprint import pprint
+from cloudmesh.common.Printer import Printer
 
 class Host(object):
 
+    def _print(results, output='table'):
+
+        if output in ['table', 'yaml']:
+            print(Printer.write(results,
+                                order=['host', 'success', 'stdout', 'stderr'],
+                                output=output))
+        else:
+            pprint(results)
+
     @staticmethod
     def get_hostnames(names):
         """
@@ -59,7 +71,7 @@ class Host(object):
             hostname = ""
             user = f"user {username}"
             if ips is None:
-                hostanme = ""
+                hostname = ""
             else:
                 ip = _ips[i]
                 hostname = f"Hostname {ip}"
@@ -100,44 +112,50 @@ class Host(object):
         :param args: command dict
         :return:
         """
-        hostname = platform_module.uname()[1]
-        host = args.get("host")
+        try:
+            # experimental sleep as we get a block on ssh commands
 
-        shell = args.get("shell")
+            hostname = platform_module.uname()[1]
+            host = args.get("host")
 
-        if host == hostname:
-            command = args.get("execute")
-            result = subprocess.getoutput(command)
-            stderr = ""
-            returncode = 0
-            stdout = result
-        else:
-            command = args.get("command")
+            shell = args.get("shell")
 
-            result = subprocess.run(
-                command,
-                capture_output=True,
-                shell=shell)
+            if host == hostname:
+                command = args.get("execute")
+                result = subprocess.getoutput(command)
+                stderr = ""
+                returncode = 0
+                stdout = result
+            else:
+                command = args.get("command")
 
-            result.stdout = result.stdout.decode("utf-8", "ignore").strip()
-            if result.stderr == b'':
-                result.stderr = None
+                result = subprocess.run(
+                    command,
+                    capture_output=True,
+                    shell=shell)
 
-            stderr = result.stderr
-            returncode = result.returncode
-            stdout = result.stdout
+                result.stdout = result.stdout.decode("utf-8", "ignore").strip()
+                if result.stderr == b'':
+                    result.stderr = None
 
-        data = {
-            'host': args.get("host"),
-            'command': args.get("command"),
-            'execute': args.get("execute"),
-            'stdout': stdout,
-            'stderr': stderr,
-            'returncode': returncode,
-            'success': returncode == 0,
-            'date': DateTime.now(),
-            'cmd': " ".join(args.get("command"))
-        }
+                stderr = result.stderr
+                returncode = result.returncode
+                stdout = result.stdout
+
+            data = {
+                'host': args.get("host"),
+                'command': args.get("command"),
+                'execute': args.get("execute"),
+                'stdout': stdout,
+                'stderr': stderr,
+                'returncode': returncode,
+                'success': returncode == 0,
+                'date': DateTime.now(),
+                'cmd': " ".join(args.get("command"))
+            }
+        except Exception as e:
+            print (e)
+            data = None
         return data
 
     @staticmethod
@@ -174,7 +192,9 @@ class Host(object):
 
         if "executor" not in args:
             _executor = Host._run
-
+        #from pprint import pprint
+        # os.sync()
+        # pprint(args)
         with Pool(processors) as p:
             res = p.map(_executor, args)
             p.close()
@@ -212,7 +232,7 @@ class Host(object):
         ssh_command = ['ssh',
                        '-o', 'StrictHostKeyChecking=no',
                        '-o', 'UserKnownHostsFile=/dev/null',
-                       '-i', f'{key}',
+                       '-i', key,
                        '{host}',
                        f'{command}']
         result = Host.run(hosts=hosts,
@@ -375,7 +395,6 @@ class Host(object):
         :return:
         """
         hosts = Parameter.expand(hosts)
-
         command = f'ssh-keygen -q -N "" -f {filename} <<< y'
         result_keys = Host.ssh(hosts=hosts,
                                command=command,
@@ -383,11 +402,11 @@ class Host(object):
                                dryrun=dryrun,
                                processors=processors,
                                executor=os.system)
+        Host._print(result_keys)
         result_keys = Host.ssh(hosts=hosts,
                                processors=processors,
                                command='cat .ssh/id_rsa.pub',
                                username=username)
-
         return result_keys
 
     @staticmethod
@@ -411,31 +430,40 @@ class Host(object):
         names = Parameter.expand(hosts)
 
         results_key = Host.ssh(hosts=names,
-                               command='cat .ssh/id_rsa.pub',
+                               command='cat ~/.ssh/id_rsa.pub',
                                username=username,
                                verbose=False)
         # results_authorized = Host.ssh(hosts=names,
         #                              command='cat .ssh/id_rsa.pub',
         #                              username=username,
         #                              verbose=False)
+
+
         filename = path_expand(filename)
+        content = readfile(filename).strip()
         localkey = {
             'host': "localhost",
             'command': [''],
             'execute': "",
-            'stdout': readfile(filename).strip(),
+            'stdout': content,
             'stderr': None,
             'returncode': True,
             'success': True,
             'date': DateTime.now()
         }
-
         if results_key is None:  # and results_authorized is None:
             return ""
 
         # getting the output and also removing duplicates
-        output = [localkey['stdout']] + list(set([element["stdout"] for element in results_key]))
 
-        output = '\n'.join(output) + "\n"
+        keys = [localkey['stdout'].strip()]
+        for element in results_key:
+            if element['stdout'] != '':
+                keys.append(element['stdout'].strip())
+
+        output = list(set(keys))
+
+        output = '\n'.join(output)
+        print (output)
 
         return output
