@@ -27,6 +27,7 @@ from cloudmesh.common.dotdict import dotdict
 from cloudmesh.common.systeminfo import get_platform
 from cloudmesh.common.util import path_expand
 from cloudmesh.common.util import readfile
+from cloudmesh.common.systeminfo import os_is_windows
 
 
 # from functools import wraps
@@ -257,7 +258,7 @@ class Shell(object):
         return str(result)
 
     @staticmethod
-    def run(command, exit="; exit 0", encoding='utf-8'):
+    def run(command, exit="; exit 0", encoding='utf-8', replace=True):
         """
         executes the command and returns the output as string
         :param command:
@@ -266,7 +267,11 @@ class Shell(object):
         """
 
         if sys.platform == "win32":
-            command = f"{command}"
+            if replace:
+                c = "&"
+            else:
+                c = ";"
+            command = f"{command}".replace(";",c)
         else:
             command = f"{command} {exit}"
 
@@ -413,7 +418,7 @@ class Shell(object):
         return result
 
     @staticmethod
-    def oneline(script):
+    def oneline(script, seperator=" && "):
         """
         converts a script to one line command.
         THis is useful to run a single ssh command and pass a one line script.
@@ -421,7 +426,7 @@ class Shell(object):
         :param script:
         :return:
         """
-        return " && ".join(textwrap.dedent(script).strip().splitlines())
+        return seperator.join(textwrap.dedent(script).strip().splitlines())
 
     @staticmethod
     def is_root():
@@ -1145,7 +1150,10 @@ class Shell(object):
         :param command: teh command
         :return: the path
         """
-        return shutil.which(command)
+        if os_is_windows():
+            return Shell.run(f"where {command}")
+        else:
+            return shutil.which(command)
 
     @classmethod
     def command_exists(cls, name):
