@@ -31,6 +31,8 @@ Here is a simple example on how to use the with statement, showing that is can b
 The mode tetermins if the file will be recreated, or if it will be appanded on. In addition there is the ability to
 write metadata into the record with a dict that can optionally be passed along.
 
+In order not to overwrite the value of an event, you must give it a unique name.
+
     from cloudmesh.common.StopWatch import StopWatchBlock
     from cloudmesh.common.StopWatch import StopWatch
     from cloudmesh.common.util import readfile
@@ -40,6 +42,8 @@ write metadata into the record with a dict that can optionally be passed along.
     data = {"step": "value"}
 
     StopWatch.event("event-start")
+    d = {"key": "value"}
+    StopWatch.event("event-with-value", d)
 
     with StopWatchBlock("total"):
         time.sleep(1.0)
@@ -64,23 +68,48 @@ write metadata into the record with a dict that can optionally be passed along.
 
     StopWatch.event("event-stop")
 
-    StopWatch.benchmark(sysinfo=False, user="gregor", node="computer",
-                        attributes=["timer", "status", "time", "start"]
+    StopWatch.benchmark(sysinfo=False,
+                        tag="myexperiment",
+                        user="gregor",
+                        node="computer",
+                        attributes=["timer", "status", "time", "start", "tag", "msg"]
+
+    # for more examples, see our pytest:
+    # * <https://github.com/cloudmesh/cloudmesh-common/blob/main/tests/test_stopwatch.py>
+    #
+    # there we demonstrate how to timers in a loop as individual timers and as sum.
+    # We also showcase how to add a message to timers
 )
 
+Integration with MLPerf Logging
 
+To also produce output that conforms to MLPerf, cloudmesh. STopWatch will detect if you have mperf logging installed.
+We recommend tho install the newest version as follows
+
+
+::
+    git clone https://github.com/mlperf/logging.git mlperf-logging
+    pip install -e mlperf-logging
+
+Now you can just use the STopwatch as before.
+
+We will add here aditional information, such as setting up the configuration for mlperf logging
 
 """
 import os
 import time
 import datetime
-from pprint import pprint
+import pprint
+
 import sys
 
+from cloudmesh.common.console import Console
 from cloudmesh.common.Tabulate import Printer
 from cloudmesh.common.systeminfo import systeminfo as cm_systeminfo
-from time import perf_counter
+from cloudmesh.common.util import writefile
+from cloudmesh.common.util import readfile
 
+from time import perf_counter
 
 def rename(newname):
     """
@@ -133,6 +162,43 @@ class StopWatch(object):
     timer_sum = {}
     # msg
     timer_msg = {}
+    # mllogger
+    timer_values = {}
+    mllogging = False
+    mllogger = None
+
+    @classmethod
+    def activate_mllog(cls, filename="cloudmesh_mllog.log"):
+        try:
+            from mlperf_logging import mllog
+        except:
+            Console.error("You need to install mllogging to use it")
+            sys.exit()
+
+        cls.mllogging = True
+        cls.mllogger = mllog.get_mllogger()
+        mllog.config(filename=filename)
+        mllog.config(
+            default_namespace="cloudmesh",
+            default_stack_offset=1,
+            default_clear_line=False,
+            # useful when refering to linenumbers in separate code
+            # root_dir=os.path.normpath(
+            #    os.path.join(os.path.dirname(os.path.realpath(__file__)), "..", ".."))
+        )
+
+    @classmethod
+    def organization_mllog(cls, configfile, **argv):
+        import mllog
+        import yaml
+        config = yaml.safe_load(readfile(configfile).strip())
+        config["benchmark"].update(argv)
+        cls.mllogger.event(key=mllog.constants.SUBMISSION_BENCHMARK, value=config["benchmark"]['name'])
+        cls.mllogger.event(key=mllog.constants.SUBMISSION_ORG, value=config["benchmark"]['organisation'])
+        cls.mllogger.event(key=mllog.constants.SUBMISSION_DIVISION, value=config["benchmark"]['division'])
+        cls.mllogger.event(key=mllog.constants.SUBMISSION_STATUS, value=config["benchmark"]['status'])
+        cls.mllogger.event(key=mllog.constants.SUBMISSION_PLATFORM, value=config["benchmark"]['platform'])
+
 
     @classmethod
     def keys(cls):
@@ -179,19 +245,31 @@ class StopWatch(object):
         cls.timer_msg[name] = value
 
     @classmethod
-    def event(cls, name):
+    def event(cls, name, msg=None, values=None):
         """
         adds an event with a given name, where start and stop is the same tme.
 
         :param name: the name of the timer
         :type name: string
+        :param data: data that is associated with the event that is converted to a string
+        :type data: object
         """
         StopWatch.start(name)
         StopWatch.stop(name)
         StopWatch.timer_end[name] = StopWatch.timer_start[name]
+        if values:
+            StopWatch.timer_values[name] = values
+
+        if msg is not None:
+            StopWatch.message(name, str(msg))
+        if cls.mllogging:
+            if values is not None:
+                cls.mllogger.event(key=f"mllog-event-{name}", value=str(values))
+            else:
+                cls.mllogger.event(key=f"mllog-event-{name}")
 
     @classmethod
-    def start(cls, name):
+    def start(cls, name, values=None):
         """
         starts a timer with the given name.
 
@@ -206,9 +284,17 @@ class StopWatch(object):
         cls.timer_end[name] = None
         cls.timer_status[name] = None
         cls.timer_msg[name] = None
+        if values:
+            StopWatch.timer_values[name] = values
+
+        if cls.mllogging:
+            if values is not None:
+                cls.mllogger.start(key=f"mllog-timer-{name}", value=str(values))
+            else:
+                cls.mllogger.start(key=f"mllog-timer-{name}")
 
     @classmethod
-    def stop(cls, name, state=True):
+    def stop(cls, name, state=True, values=None):
         """
         stops the timer with a given name.
 
@@ -220,6 +306,15 @@ class StopWatch(object):
         #    cls.timer_end[name] = cls.timer_end[name] + cls.timer_last[name]
         cls.timer_sum[name] = cls.timer_sum[name] + cls.timer_end[name] - cls.timer_start[name]
         cls.timer_status[name] = state
+        if values:
+            StopWatch.timer_values[name] = values
+
+        if cls.mllogging:
+            if values is not None:
+                cls.mllogger.end(key=f"mllog-timer-{name}", value=str(values))
+            else:
+                cls.mllogger.end(key=f"mllog-timer-{name}")
+
 
         if cls.debug:
             print("Timer", name, "stopped ...")
@@ -452,6 +547,7 @@ class StopWatch(object):
     @classmethod
     def benchmark(cls,
                   sysinfo=True,
+                  timers=True,
                   csv=True,
                   prefix="# csv",
                   tag=None,
@@ -459,7 +555,8 @@ class StopWatch(object):
                   node=None,
                   user=None,
                   attributes=None,
-                  total=False):
+                  total=False,
+                  filename=None):
         """
         prints out all timers in a convenient benchmark table
 
@@ -486,145 +583,156 @@ class StopWatch(object):
         #
         # PRINT PLATFORM
         #
+        content = "\n"
 
-        print()
         data_platform = cm_systeminfo(user=user, node=node)
         if sysinfo:
-            print(Printer.attribute(
+            content = content + Printer.attribute(
                 data_platform,
                 order=["Machine Attribute", "Value"],
                 output="table"
-            ))
+            )
+            content = content + "\n"
 
-        #
-        # PRINT TIMERS
-        #
-        timers = StopWatch.keys()
-        total_time = 0.0
-        if len(timers) > 0:
+        if timers:
 
-            data_timers = {}
-            for timer in timers:
-                data_timers[timer] = {
-                    'start': time.strftime("%Y-%m-%d %H:%M:%S",
-                                           time.gmtime(
-                                               StopWatch.timer_start[timer])),
-                    'time': StopWatch.get(timer, digits=3),
-                    'sum': StopWatch.sum(timer, digits=3),
-                    'status': StopWatch.get_status(timer),
-                    'msg': StopWatch.get_message(timer),
-                    'timer': timer,
-                    'tag': tag or ''
-                }
-                try:
-                    total_time = total_time + StopWatch.get(timer)
-                except:
-                    pass
-                for attribute in ["uname.node",
-                                  "user",
-                                  "uname.system",
-                                  "uname.machine",
-                                  "platform.version",
-                                  "sys.platform"]:
-                    if attribute == "user" and user is not None:
-                        data_timers[timer][attribute] = user
-                    elif attribute == "uname.node" and node is not None:
-                        data_timers[timer][attribute] = node
-                    else:
-                        data_timers[timer][attribute] = data_platform[attribute]
+            #
+            # PRINT TIMERS
+            #
+            timers = StopWatch.keys()
+            total_time = 0.0
+            if len(timers) > 0:
 
-            # print(Printer.attribute(data_timers, header=["Command", "Time/s"]))
+                data_timers = {}
+                for timer in timers:
+                    data_timers[timer] = {
+                        'start': time.strftime("%Y-%m-%d %H:%M:%S",
+                                               time.gmtime(
+                                                   StopWatch.timer_start[timer])),
+                        'time': StopWatch.get(timer, digits=3),
+                        'sum': StopWatch.sum(timer, digits=3),
+                        'status': StopWatch.get_status(timer),
+                        'msg': StopWatch.get_message(timer),
+                        'timer': timer,
+                        'tag': tag or ''
+                    }
+                    try:
+                        total_time = total_time + StopWatch.get(timer)
+                    except:
+                        pass
+                    for attribute in ["uname.node",
+                                      "user",
+                                      "uname.system",
+                                      "uname.machine",
+                                      "platform.version",
+                                      "sys.platform"]:
+                        if attribute == "user" and user is not None:
+                            data_timers[timer][attribute] = user
+                        elif attribute == "uname.node" and node is not None:
+                            data_timers[timer][attribute] = node
+                        else:
+                            data_timers[timer][attribute] = data_platform[attribute]
 
-            if 'benchmark_start_stop' in data_timers:
-                del data_timers['benchmark_start_stop']
+                # print(Printer.attribute(data_timers, header=["Command", "Time/s"]))
 
-            for key in data_timers:
-                if key != 'benchmark_start_stop' and data_timers[key]['status'] is None:
-                    data_timers[key]['status'] = "failed"
-                elif data_timers[key]['status'] is not None and data_timers[key]['status']:
-                    data_timers[key]['status'] = "ok"
+                if 'benchmark_start_stop' in data_timers:
+                    del data_timers['benchmark_start_stop']
 
-            if attributes is None:
-                order = [
-                    "timer",
-                    "status",
-                    "time",
-                    "sum",
-                    "start",
-                    "tag",
-                    "msg",
-                    "uname.node",
-                    "user",
-                    "uname.system",
-                    "platform.version"
-                ]
+                for key in data_timers:
+                    if key != 'benchmark_start_stop' and data_timers[key]['status'] is None:
+                        data_timers[key]['status'] = "failed"
+                    elif data_timers[key]['status'] is not None and data_timers[key]['status']:
+                        data_timers[key]['status'] = "ok"
 
-                header = [
-                    "Name",
-                    "Status",
-                    "Time",
-                    "Sum",
-                    "Start",
-                    "tag",
-                    "msg",
-                    "Node",
-                    "User",
-                    "OS",
-                    "Version"
-                ]
-            elif attributes == "short":
-                order = [
-                    "timer",
-                    "status",
-                    "time"
-                ]
+                if attributes is None:
+                    order = [
+                        "timer",
+                        "status",
+                        "time",
+                        "sum",
+                        "start",
+                        "tag",
+                        "msg",
+                        "uname.node",
+                        "user",
+                        "uname.system",
+                        "platform.version"
+                    ]
 
-                header = [
-                    "Name",
-                    "Status",
-                    "Time"
-                ]
-            else:
-                order = attributes
-                header = attributes
-            print()
-            print(Printer.write(
-                data_timers,
-                order=order,
-                header=header,
-                output="table"
+                    header = [
+                        "Name",
+                        "Status",
+                        "Time",
+                        "Sum",
+                        "Start",
+                        "tag",
+                        "msg",
+                        "Node",
+                        "User",
+                        "OS",
+                        "Version"
+                    ]
+                elif attributes == "short":
+                    order = [
+                        "timer",
+                        "status",
+                        "time"
+                    ]
 
-            ))
-            if total:
-                print("Total:", total_time)
-            print()
-
-            if csv:
-                if prefix is not None:
-                    for entry in data_timers:
-                        data_timers[entry]["# csv"] = prefix
-
-                    order = ["# csv"] + order
-
-                    print(Printer.write(
-                        data_timers,
-                        order=order,
-                        header=header,
-                        output="csv"
-                    ))
+                    header = [
+                        "Name",
+                        "Status",
+                        "Time"
+                    ]
                 else:
+                    order = attributes
+                    header = attributes
+                content = content + "\n"
+                content = content + Printer.write(
+                    data_timers,
+                    order=order,
+                    header=header,
+                    output="table"
 
-                    pprint(data_timers)
+                )
 
-                    print(Printer.write(
-                        data_timers,
-                        order=order[1:],
-                        output="csv"
-                    ))
+                if total:
+                    content = content + f"Total: {total_time}"
 
-        else:
+                content = content + "\n"
+
+                if csv:
+                    if prefix is not None:
+                        for entry in data_timers:
+                            data_timers[entry]["# csv"] = prefix
+
+                        order = ["# csv"] + order
+
+                        content = content + Printer.write(
+                            data_timers,
+                            order=order,
+                            header=header,
+                            output="csv"
+                        )
+                    else:
+
+                        content = content + pprint.pformat(data_timers, indent=4)
+                        content = content + "\n"
+
+                        content = content + Printer.write(
+                            data_timers,
+                            order=order[1:],
+                            output="csv"
+                        )
+                        content = content + "\n"
+
+            else:
+                content = content + "ERROR: No timers found\n"
+
+        print(content)
+        if filename:
+            writefile(filename, content)
 
-            print("ERROR: No timers found")
 
     def load(filename,
              label=["name"], label_split_char=" ",
