@@ -51,7 +51,7 @@ if py3k:
     iterzip = zip
     uni_chr = chr
     from html.parser import HTMLParser
-else: 
+else:
     itermap = itertools.imap
     iterzip = itertools.izip
     uni_chr = unichr
@@ -64,8 +64,8 @@ else:
 
 # hrule styles
 FRAME = 0
-ALL   = 1
-NONE  = 2
+ALL = 1
+NONE = 2
 HEADER = 3
 
 # Table styles
@@ -74,6 +74,7 @@ MSWORD_FRIENDLY = 11
 PLAIN_COLUMNS = 12
 RANDOM = 20
 
+
 def _get_size(text):
     lines = text.splitlines()
     height = len(lines)
@@ -82,7 +83,8 @@ def _get_size(text):
     else:
         width = 0
     return (width, height)
-        
+
+
 class PrettyTable(object):
 
     def __init__(self, field_names=None, **kwargs):
@@ -169,10 +171,10 @@ class PrettyTable(object):
         self._vertical_char = kwargs["vertical_char"] or self._unicode("|")
         self._horizontal_char = kwargs["horizontal_char"] or self._unicode("-")
         self._junction_char = kwargs["junction_char"] or self._unicode("+")
-        
+
         self._format = kwargs["format"] or False
         self._attributes = kwargs["attributes"] or {}
-   
+
     def _unicode(self, value):
         if not isinstance(value, basestring):
             value = str(value)
@@ -191,15 +193,15 @@ class PrettyTable(object):
                 # Uneven padding
                 # Put more space on right if text is of odd length...
                 if _str_block_width(text) % 2:
-                    return (excess//2)*" " + text + (excess//2 + 1)*" "
+                    return (excess // 2) * " " + text + (excess // 2 + 1) * " "
                 # and more space on left if text is of even length
                 else:
-                    return (excess//2 + 1)*" " + text + (excess//2)*" "
+                    return (excess // 2 + 1) * " " + text + (excess // 2) * " "
                 # Why distribute extra space this way?  To match the behaviour of
                 # the inbuilt str.center() method.
             else:
                 # Equal padding on either side
-                return (excess//2)*" " + text + (excess//2)*" "
+                return (excess // 2) * " " + text + (excess // 2) * " "
 
     def __getattr__(self, name):
 
@@ -214,13 +216,13 @@ class PrettyTable(object):
                 return 0
         else:
             raise AttributeError(name)
- 
+
     def __getitem__(self, index):
 
         new = PrettyTable()
         new.field_names = self.field_names
         for attr in self._options:
-            setattr(new, "_"+attr, getattr(self, "_"+attr))
+            setattr(new, "_" + attr, getattr(self, "_" + attr))
         setattr(new, "_align", getattr(self, "_align"))
         if isinstance(index, slice):
             for row in self._rows[index]:
@@ -233,10 +235,10 @@ class PrettyTable(object):
 
     if py3k:
         def __str__(self):
-           return self.__unicode__()
+            return self.__unicode__()
     else:
         def __str__(self):
-           return self.__unicode__().encode(self.encoding)
+            return self.__unicode__().encode(self.encoding)
 
     def __unicode__(self):
         return self.get_string()
@@ -255,7 +257,8 @@ class PrettyTable(object):
     def _validate_option(self, option, val):
         if option in ("field_names"):
             self._validate_field_names(val)
-        elif option in ("start", "end", "max_width", "padding_width", "left_padding_width", "right_padding_width", "format"):
+        elif option in (
+        "start", "end", "max_width", "padding_width", "left_padding_width", "right_padding_width", "format"):
             self._validate_nonnegative_int(option, val)
         elif option in ("sortby"):
             self._validate_field_name(option, val)
@@ -286,14 +289,16 @@ class PrettyTable(object):
         # Check for appropriate length
         if self._field_names:
             try:
-               assert len(val) == len(self._field_names)
+                assert len(val) == len(self._field_names)
             except AssertionError:
-               raise Exception("Field name list has incorrect number of values, (actual) %d!=%d (expected)" % (len(val), len(self._field_names)))
+                raise Exception("Field name list has incorrect number of values, (actual) %d!=%d (expected)" % (
+                len(val), len(self._field_names)))
         if self._rows:
             try:
-               assert len(val) == len(self._rows[0])
+                assert len(val) == len(self._rows[0])
             except AssertionError:
-               raise Exception("Field name list has incorrect number of values, (actual) %d!=%d (expected)" % (len(val), len(self._rows[0])))
+                raise Exception("Field name list has incorrect number of values, (actual) %d!=%d (expected)" % (
+                len(val), len(self._rows[0])))
         # Check for uniqueness
         try:
             assert len(val) == len(set(val))
@@ -308,13 +313,13 @@ class PrettyTable(object):
 
     def _validate_align(self, val):
         try:
-            assert val in ["l","c","r"]
+            assert val in ["l", "c", "r"]
         except AssertionError:
             raise Exception("Alignment %s is invalid, use l, c or r!" % val)
 
     def _validate_valign(self, val):
         try:
-            assert val in ["t","m","b",None]
+            assert val in ["t", "m", "b", None]
         except AssertionError:
             raise Exception("Alignment %s is invalid, use t, m, b or None!" % val)
 
@@ -406,6 +411,7 @@ class PrettyTable(object):
         Arguments:
 
         fields - list or tuple of field names"""
+
     def _set_field_names(self, val):
         val = [self._unicode(x) for x in val]
         self._validate_option("field_names", val)
@@ -430,32 +436,39 @@ class PrettyTable(object):
         else:
             for field in self._field_names:
                 self._valign[field] = "t"
+
     field_names = property(_get_field_names, _set_field_names)
 
     def _get_align(self):
         return self._align
+
     def _set_align(self, val):
         self._validate_align(val)
         for field in self._field_names:
             self._align[field] = val
+
     align = property(_get_align, _set_align)
 
     def _get_valign(self):
         return self._valign
+
     def _set_valign(self, val):
         self._validate_valign(val)
         for field in self._field_names:
             self._valign[field] = val
+
     valign = property(_get_valign, _set_valign)
 
     def _get_max_width(self):
         return self._max_width
+
     def _set_max_width(self, val):
         self._validate_option("max_width", val)
         for field in self._field_names:
             self._max_width[field] = val
+
     max_width = property(_get_max_width, _set_max_width)
-    
+
     def _get_fields(self):
         """List or tuple of field names to include in displays
 
@@ -463,9 +476,11 @@ class PrettyTable(object):
 
         fields - list or tuple of field names to include in displays"""
         return self._fields
+
     def _set_fields(self, val):
         self._validate_option("fields", val)
         self._fields = val
+
     fields = property(_get_fields, _set_fields)
 
     def _get_start(self):
@@ -479,6 +494,7 @@ class PrettyTable(object):
     def _set_start(self, val):
         self._validate_option("start", val)
         self._start = val
+
     start = property(_get_start, _set_start)
 
     def _get_end(self):
@@ -488,9 +504,11 @@ class PrettyTable(object):
 
         end - index of last data row to include in output PLUS ONE (list slice style)"""
         return self._end
+
     def _set_end(self, val):
         self._validate_option("end", val)
         self._end = val
+
     end = property(_get_end, _set_end)
 
     def _get_sortby(self):
@@ -500,9 +518,11 @@ class PrettyTable(object):
 
         sortby - field name to sort by"""
         return self._sortby
+
     def _set_sortby(self, val):
         self._validate_option("sortby", val)
         self._sortby = val
+
     sortby = property(_get_sortby, _set_sortby)
 
     def _get_reversesort(self):
@@ -512,9 +532,11 @@ class PrettyTable(object):
 
         reveresort - set to True to sort by descending order, or False to sort by ascending order"""
         return self._reversesort
+
     def _set_reversesort(self, val):
         self._validate_option("reversesort", val)
         self._reversesort = val
+
     reversesort = property(_get_reversesort, _set_reversesort)
 
     def _get_sort_key(self):
@@ -524,11 +546,13 @@ class PrettyTable(object):
 
         sort_key - a function which takes one argument and returns something to be sorted"""
         return self._sort_key
+
     def _set_sort_key(self, val):
         self._validate_option("sort_key", val)
         self._sort_key = val
+
     sort_key = property(_get_sort_key, _set_sort_key)
- 
+
     def _get_header(self):
         """Controls printing of table header with field names
 
@@ -536,9 +560,11 @@ class PrettyTable(object):
 
         header - print a header showing field names (True or False)"""
         return self._header
+
     def _set_header(self, val):
         self._validate_option("header", val)
         self._header = val
+
     header = property(_get_header, _set_header)
 
     def _get_header_style(self):
@@ -548,9 +574,11 @@ class PrettyTable(object):
 
         header_style - stylisation to apply to field names in header ("cap", "title", "upper", "lower" or None)"""
         return self._header_style
+
     def _set_header_style(self, val):
         self._validate_header_style(val)
         self._header_style = val
+
     header_style = property(_get_header_style, _set_header_style)
 
     def _get_border(self):
@@ -560,9 +588,11 @@ class PrettyTable(object):
 
         border - print a border around the table (True or False)"""
         return self._border
+
     def _set_border(self, val):
         self._validate_option("border", val)
         self._border = val
+
     border = property(_get_border, _set_border)
 
     def _get_hrules(self):
@@ -572,9 +602,11 @@ class PrettyTable(object):
 
         hrules - horizontal rules style.  Allowed values: FRAME, ALL, HEADER, NONE"""
         return self._hrules
+
     def _set_hrules(self, val):
         self._validate_option("hrules", val)
         self._hrules = val
+
     hrules = property(_get_hrules, _set_hrules)
 
     def _get_vrules(self):
@@ -584,9 +616,11 @@ class PrettyTable(object):
 
         vrules - vertical rules style.  Allowed values: FRAME, ALL, NONE"""
         return self._vrules
+
     def _set_vrules(self, val):
         self._validate_option("vrules", val)
         self._vrules = val
+
     vrules = property(_get_vrules, _set_vrules)
 
     def _get_int_format(self):
@@ -595,10 +629,12 @@ class PrettyTable(object):
 
         int_format - integer format string"""
         return self._int_format
+
     def _set_int_format(self, val):
-#        self._validate_option("int_format", val)
+        #        self._validate_option("int_format", val)
         for field in self._field_names:
             self._int_format[field] = val
+
     int_format = property(_get_int_format, _set_int_format)
 
     def _get_float_format(self):
@@ -607,10 +643,12 @@ class PrettyTable(object):
 
         float_format - floating point format string"""
         return self._float_format
+
     def _set_float_format(self, val):
-#        self._validate_option("float_format", val)
+        #        self._validate_option("float_format", val)
         for field in self._field_names:
             self._float_format[field] = val
+
     float_format = property(_get_float_format, _set_float_format)
 
     def _get_padding_width(self):
@@ -620,9 +658,11 @@ class PrettyTable(object):
 
         padding_width - number of spaces, must be a positive integer"""
         return self._padding_width
+
     def _set_padding_width(self, val):
         self._validate_option("padding_width", val)
         self._padding_width = val
+
     padding_width = property(_get_padding_width, _set_padding_width)
 
     def _get_left_padding_width(self):
@@ -632,9 +672,11 @@ class PrettyTable(object):
 
         left_padding - number of spaces, must be a positive integer"""
         return self._left_padding_width
+
     def _set_left_padding_width(self, val):
         self._validate_option("left_padding_width", val)
         self._left_padding_width = val
+
     left_padding_width = property(_get_left_padding_width, _set_left_padding_width)
 
     def _get_right_padding_width(self):
@@ -644,9 +686,11 @@ class PrettyTable(object):
 
         right_padding - number of spaces, must be a positive integer"""
         return self._right_padding_width
+
     def _set_right_padding_width(self, val):
         self._validate_option("right_padding_width", val)
         self._right_padding_width = val
+
     right_padding_width = property(_get_right_padding_width, _set_right_padding_width)
 
     def _get_vertical_char(self):
@@ -656,10 +700,12 @@ class PrettyTable(object):
 
         vertical_char - single character string used to draw vertical lines"""
         return self._vertical_char
+
     def _set_vertical_char(self, val):
         val = self._unicode(val)
         self._validate_option("vertical_char", val)
         self._vertical_char = val
+
     vertical_char = property(_get_vertical_char, _set_vertical_char)
 
     def _get_horizontal_char(self):
@@ -669,10 +715,12 @@ class PrettyTable(object):
 
         horizontal_char - single character string used to draw horizontal lines"""
         return self._horizontal_char
+
     def _set_horizontal_char(self, val):
         val = self._unicode(val)
         self._validate_option("horizontal_char", val)
         self._horizontal_char = val
+
     horizontal_char = property(_get_horizontal_char, _set_horizontal_char)
 
     def _get_junction_char(self):
@@ -682,10 +730,12 @@ class PrettyTable(object):
 
         junction_char - single character string used to draw line junctions"""
         return self._junction_char
+
     def _set_junction_char(self, val):
         val = self._unicode(val)
         self._validate_option("vertical_char", val)
         self._junction_char = val
+
     junction_char = property(_get_junction_char, _set_junction_char)
 
     def _get_format(self):
@@ -695,9 +745,11 @@ class PrettyTable(object):
 
         format - True or False"""
         return self._format
+
     def _set_format(self, val):
         self._validate_option("format", val)
         self._format = val
+
     format = property(_get_format, _set_format)
 
     def _get_attributes(self):
@@ -711,6 +763,7 @@ class PrettyTable(object):
     def _set_attributes(self, val):
         self._validate_option("attributes", val)
         self._attributes = val
+
     attributes = property(_get_attributes, _set_attributes)
 
     ##############################
@@ -725,7 +778,7 @@ class PrettyTable(object):
                 self._validate_option(option, kwargs[option])
                 options[option] = kwargs[option]
             else:
-                options[option] = getattr(self, "_"+option)
+                options[option] = getattr(self, "_" + option)
         return options
 
     ##############################
@@ -783,8 +836,8 @@ class PrettyTable(object):
         self.border = random.choice((True, False))
         self._hrules = random.choice((ALL, FRAME, HEADER, NONE))
         self._vrules = random.choice((ALL, FRAME, NONE))
-        self.left_padding_width = random.randint(0,5)
-        self.right_padding_width = random.randint(0,5)
+        self.left_padding_width = random.randint(0, 5)
+        self.right_padding_width = random.randint(0, 5)
         #
         # Gregor von Laszewski, add an r in foront of the next strings so its not deprecated
         #
@@ -806,9 +859,10 @@ class PrettyTable(object):
         has fields"""
 
         if self._field_names and len(row) != len(self._field_names):
-            raise Exception("Row has incorrect number of values, (actual) %d!=%d (expected)" %(len(row),len(self._field_names)))
+            raise Exception(
+                "Row has incorrect number of values, (actual) %d!=%d (expected)" % (len(row), len(self._field_names)))
         if not self._field_names:
-            self.field_names = [("Field %d" % (n+1)) for n in range(0,len(row))]
+            self.field_names = [("Field %d" % (n + 1)) for n in range(0, len(row))]
         self._rows.append(list(row))
 
     def del_row(self, row_index):
@@ -819,7 +873,7 @@ class PrettyTable(object):
 
         row_index - The index of the row you want to delete.  Indexing starts at 0."""
 
-        if row_index > len(self._rows)-1:
+        if row_index > len(self._rows) - 1:
             raise Exception("Cant delete row at index %d, table only has %d rows!" % (row_index, len(self._rows)))
         del self._rows[row_index]
 
@@ -842,7 +896,7 @@ class PrettyTable(object):
             self._align[fieldname] = align
             self._valign[fieldname] = valign
             for i in range(0, len(column)):
-                if len(self._rows) < i+1:
+                if len(self._rows) < i + 1:
                     self._rows.append([])
                 self._rows[i].append(column[i])
         else:
@@ -912,26 +966,26 @@ class PrettyTable(object):
         Arguments:
 
         options - dictionary of option settings."""
-       
-        # Make a copy of only those rows in the slice range 
+
+        # Make a copy of only those rows in the slice range
         rows = copy.deepcopy(self._rows[options["start"]:options["end"]])
         # Sort if necessary
         if options["sortby"]:
             sortindex = self._field_names.index(options["sortby"])
             # Decorate
-            rows = [[row[sortindex]]+row for row in rows]
+            rows = [[row[sortindex]] + row for row in rows]
             # Sort
             rows.sort(reverse=options["reversesort"], key=options["sort_key"])
             # Undecorate
             rows = [row[1:] for row in rows]
         return rows
-        
+
     def _format_row(self, row, options):
         return [self._format_value(field, value) for (field, value) in zip(self._field_names, row)]
 
     def _format_rows(self, rows, options):
         return [self._format_row(row, options) for row in rows]
- 
+
     ##############################
     # PLAIN TEXT STRING METHODS  #
     ##############################
@@ -993,7 +1047,7 @@ class PrettyTable(object):
         # Add bottom of border
         if options["border"] and options["hrules"] == FRAME:
             lines.append(self._hrule)
-        
+
         return self._unicode("\n").join(lines)
 
     def _stringify_hrule(self, options):
@@ -1005,7 +1059,7 @@ class PrettyTable(object):
         for field, width in zip(self._field_names, self._widths):
             if options["fields"] and field not in options["fields"]:
                 continue
-            bits.append((width+lpad+rpad)*options["horizontal_char"])
+            bits.append((width + lpad + rpad) * options["horizontal_char"])
             bits.append(options["junction_char"])
         return "".join(bits)
 
@@ -1051,12 +1105,12 @@ class PrettyTable(object):
         return "".join(bits)
 
     def _stringify_row(self, row, options):
-       
-        for index, field, value, width, in zip(range(0,len(row)), self._field_names, row, self._widths):
+
+        for index, field, value, width, in zip(range(0, len(row)), self._field_names, row, self._widths):
             # Enforce max widths
             lines = value.splitlines()
             new_lines = []
-            for line in lines: 
+            for line in lines:
                 if _str_block_width(line) > width:
                     line = textwrap.fill(line, width)
                 new_lines.append(line)
@@ -1087,11 +1141,11 @@ class PrettyTable(object):
             dHeight = row_height - len(lines)
             if dHeight:
                 if valign == "m":
-                  lines = [""] * int(dHeight / 2) + lines + [""] * (dHeight - int(dHeight / 2))
+                    lines = [""] * int(dHeight / 2) + lines + [""] * (dHeight - int(dHeight / 2))
                 elif valign == "b":
-                  lines = [""] * dHeight + lines
+                    lines = [""] * dHeight + lines
                 else:
-                  lines = lines + [""] * dHeight
+                    lines = lines + [""] * dHeight
 
             y = 0
             for l in lines:
@@ -1112,10 +1166,10 @@ class PrettyTable(object):
             if options["border"] and options["vrules"] == FRAME:
                 bits[y].pop()
                 bits[y].append(options["vertical_char"])
-        
-        if options["border"] and options["hrules"]== ALL:
-            bits[row_height-1].append("\n")
-            bits[row_height-1].append(self._hrule)
+
+        if options["border"] and options["hrules"] == ALL:
+            bits[row_height - 1].append("\n")
+            bits[row_height - 1].append(self._hrule)
 
         for y in range(0, row_height):
             bits[y] = "".join(bits[y])
@@ -1227,7 +1281,8 @@ class PrettyTable(object):
             for field in self._field_names:
                 if options["fields"] and field not in options["fields"]:
                     continue
-                lines.append("        <th style=\"padding-left: %dem; padding-right: %dem; text-align: center\">%s</th>" % (lpad, rpad, escape(field).replace("\n", "<br />")))
+                lines.append("        <th style=\"padding-left: %dem; padding-right: %dem; text-align: center\">%s</th>" % (
+                lpad, rpad, escape(field).replace("\n", "<br />")))
             lines.append("    </tr>")
 
         # Data
@@ -1236,27 +1291,30 @@ class PrettyTable(object):
         aligns = []
         valigns = []
         for field in self._field_names:
-            aligns.append({ "l" : "left", "r" : "right", "c" : "center" }[self._align[field]])
-            valigns.append({"t" : "top", "m" : "middle", "b" : "bottom"}[self._valign[field]])
+            aligns.append({"l": "left", "r": "right", "c": "center"}[self._align[field]])
+            valigns.append({"t": "top", "m": "middle", "b": "bottom"}[self._valign[field]])
         for row in formatted_rows:
             lines.append("    <tr>")
             for field, datum, align, valign in zip(self._field_names, row, aligns, valigns):
                 if options["fields"] and field not in options["fields"]:
                     continue
-                lines.append("        <td style=\"padding-left: %dem; padding-right: %dem; text-align: %s; vertical-align: %s\">%s</td>" % (lpad, rpad, align, valign, escape(datum).replace("\n", "<br />")))
+                lines.append(
+                    "        <td style=\"padding-left: %dem; padding-right: %dem; text-align: %s; vertical-align: %s\">%s</td>" % (
+                    lpad, rpad, align, valign, escape(datum).replace("\n", "<br />")))
             lines.append("    </tr>")
         lines.append("</table>")
 
         return self._unicode("\n").join(lines)
 
+
 ##############################
 # UNICODE WIDTH FUNCTIONS    #
 ##############################
 
 def _char_block_width(char):
     # Basic Latin, which is probably the most common case
-    #if char in xrange(0x0021, 0x007e):
-    #if char >= 0x0021 and char <= 0x007e:
+    # if char in xrange(0x0021, 0x007e):
+    # if char >= 0x0021 and char <= 0x007e:
     if 0x0021 <= char <= 0x007e:
         return 1
     # Chinese, Japanese, Korean (common)
@@ -1286,16 +1344,16 @@ def _char_block_width(char):
     # Take a guess
     return 1
 
-def _str_block_width(val):
 
+def _str_block_width(val):
     return sum(itermap(_char_block_width, itermap(ord, val)))
 
+
 ##############################
 # TABLE FACTORIES            #
 ##############################
 
-def from_csv(fp, field_names = None, **kwargs):
-
+def from_csv(fp, field_names=None, **kwargs):
     dialect = csv.Sniffer().sniff(fp.read(1024))
     fp.seek(0)
     reader = csv.reader(fp, dialect)
@@ -1314,8 +1372,8 @@ def from_csv(fp, field_names = None, **kwargs):
 
     return table
 
-def from_db_cursor(cursor, **kwargs):
 
+def from_db_cursor(cursor, **kwargs):
     if cursor.description:
         table = PrettyTable(**kwargs)
         table.field_names = [col[0] for col in cursor.description]
@@ -1323,6 +1381,7 @@ def from_db_cursor(cursor, **kwargs):
             table.add_row(row)
         return table
 
+
 class TableHandler(HTMLParser):
 
     def __init__(self, **kwargs):
@@ -1336,12 +1395,12 @@ class TableHandler(HTMLParser):
         self.last_content = ""
         self.is_last_row_header = False
 
-    def handle_starttag(self,tag, attrs):
+    def handle_starttag(self, tag, attrs):
         self.active = tag
         if tag == "th":
             self.is_last_row_header = True
 
-    def handle_endtag(self,tag):
+    def handle_endtag(self, tag):
         if tag in ["th", "td"]:
             stripped_content = self.last_content.strip()
             self.last_row.append(stripped_content)
@@ -1358,7 +1417,6 @@ class TableHandler(HTMLParser):
         self.last_content = " "
         self.active = None
 
-
     def handle_data(self, data):
         self.last_content += data
 
@@ -1370,10 +1428,10 @@ class TableHandler(HTMLParser):
         for row in self.rows:
             if len(row[0]) < self.max_row_width:
                 appends = self.max_row_width - len(row[0])
-                for i in range(1,appends):
+                for i in range(1, appends):
                     row[0].append("-")
 
-            if row[1] == True:
+            if row[1]:
                 self.make_fields_unique(row[0])
                 table.field_names = row[0]
             else:
@@ -1385,10 +1443,11 @@ class TableHandler(HTMLParser):
         iterates over the row and make each field unique
         """
         for i in range(0, len(fields)):
-            for j in range(i+1, len(fields)):
+            for j in range(i + 1, len(fields)):
                 if fields[i] == fields[j]:
                     fields[j] += "'"
 
+
 def from_html(html_code, **kwargs):
     """
     Generates a list of PrettyTables from a string of HTML code. Each <table> in
@@ -1399,6 +1458,7 @@ def from_html(html_code, **kwargs):
     parser.feed(html_code)
     return parser.tables
 
+
 def from_html_one(html_code, **kwargs):
     """
     Generates a PrettyTables from a string of HTML code which contains only a
@@ -1412,18 +1472,18 @@ def from_html_one(html_code, **kwargs):
         raise Exception("More than one <table> in provided HTML code!  Use from_html instead.")
     return tables[0]
 
+
 ##############################
 # MAIN (TEST FUNCTION)       #
 ##############################
 
 def main():
-
     x = PrettyTable(["City name", "Area", "Population", "Annual Rainfall"])
     x.sortby = "Population"
     x.reversesort = True
     x.int_format["Area"] = "04d"
     x.float_format = "6.1f"
-    x.align["City name"] = "l" # Left align city names
+    x.align["City name"] = "l"  # Left align city names
     x.add_row(["Adelaide", 1295, 1158259, 600.5])
     x.add_row(["Brisbane", 5905, 1857594, 1146.4])
     x.add_row(["Darwin", 112, 120900, 1714.7])
@@ -1432,6 +1492,7 @@ def main():
     x.add_row(["Melbourne", 1566, 3806092, 646.9])
     x.add_row(["Perth", 5386, 1554769, 869.4])
     print(x)
-    
+
+
 if __name__ == "__main__":
     main()
