@@ -1,8 +1,13 @@
 import platform
 import sys
 import os
+import socket
 from pathlib import Path
 from cloudmesh.common.util import readfile
+from cloudmesh.common.util import is_gitbash
+from cloudmesh.common.util import is_powershell
+from cloudmesh.common.util import is_cmd_exe
+from cloudmesh.common.util import is_local
 from collections import OrderedDict
 import pip
 import psutil
@@ -10,7 +15,63 @@ import humanize
 import re
 import multiprocessing
 
+
+def os_is_windows():
+    """
+    Checks if the os is windows
+
+    :return: True is windows
+    :rtype: bool
+    """
+    return platform.system() == "Windows"
+
+
+# noinspection PyBroadException
+def os_is_linux():
+    """
+    Checks if the os is linux
+
+    :return: True is linux
+    :rtype: bool
+    """
+    try:
+        content = readfile('/etc/os-release')
+        return platform.system() == "Linux" and "raspbian" not in content
+    except:  # noqa: E722
+        return False
+
+
+def os_is_mac():
+    """
+    Checks if the os is macOS
+
+    :return: True is macOS
+    :rtype: bool
+    """
+    return platform.system() == "Darwin"
+
+
+# noinspection PyBroadException
+def os_is_pi():
+    """
+    Checks if the os is Raspberry OS
+
+    :return: True is Raspberry OS
+    :rtype: bool
+    """
+    try:
+        content = readfile('/etc/os-release')
+        return platform.system() == "Linux" and "raspbian" in content
+    except:  # noqa: E722
+        return False
+
 def sys_user():
+    """
+    TODO
+
+    Returns:
+
+    """
     if "COLAB_GPU" in os.environ:
         return "collab"
     try:
@@ -30,7 +91,14 @@ def sys_user():
 
     return "None"
 
+
 def get_platform():
+    """
+    TODO
+
+    Returns:
+
+    """
     if sys.platform == "darwin":
         return "macos"
     elif sys.platform == "win32":
@@ -46,6 +114,17 @@ def get_platform():
 
 
 def systeminfo(info=None, user=None, node=None):
+    """
+    TODO
+
+    Args:
+        info (TODO):  TODO
+        user (str): TODO
+        node (str): TODO
+
+    Returns: dict of the info
+
+    """
     uname = platform.uname()
     mem = psutil.virtual_memory()
 
