@@ -9,6 +9,7 @@ import shutil
 import tempfile
 import time
 from contextlib import contextmanager
+from getpass import getpass
 import sys
 import psutil
 import requests
@@ -18,6 +19,7 @@ import pyfiglet
 import socket
 import platform
 
+
 try:
     collectionsAbc = collections.abc
 except AttributeError:
@@ -43,25 +45,34 @@ def tempdir(*args, **kwargs):
         shutil.rmtree(d)
 
 
-def check_root(terminate=True):
+def check_root(dryrun=False, terminate=True):
     """
-    Tests if the root user is used
-
-    :param terminate: if true exist the program
-    :return:
+    check if I am the root user. If not, simply exits the program.
+    :param dryrun: if set to true, does not terminate if not root user
+    :type dryrun: bool
+    :param terminate: terminates if not root user and dryrun is False
+    :type terminate: bool
     """
     uid = os.getuid()
     if uid == 0:
-        Console.ok("You are executing a a root user")
+        Console.ok("You are executing as a root user")
     else:
         Console.error("You do not run as root")
-        if terminate:
+        if terminate and not dryrun:
             sys.exit()
 
 
 def exponential_backoff(fn, sleeptime_s_max=30 * 60):
-    """Calls `fn` until it returns True, with an exponentially increasing wait time between calls"""
+    """
+    Calls `fn` until it returns True, with an exponentially increasing wait
+    time between calls
 
+    :param fn: the function to be called that returns Truw or False
+    :type fn: object
+    :param sleeptime_s_max: the sleep time in milliseconds
+    :type sleeptime_s_max: int
+    :return: None
+    """
     sleeptime_ms = 500
     while True:
         if fn():
@@ -128,12 +139,11 @@ def grep(pattern, filename):
         return ''
 
 
-
 def is_local(host):
     """
     Checks if the host is the localhost
 
-    :param host: The hotsname or ip
+    :param host: The hostname or ip
     :return: True if the host is the localhost
     """
     return host in ["127.0.0.1",
@@ -144,6 +154,7 @@ def is_local(host):
                     socket.gethostbyaddr(socket.gethostname())[0]
                     ]
 
+
 # noinspection PyPep8
 def is_gitbash():
     """
@@ -186,6 +197,7 @@ def is_cmd_exe():
             return False
 
 
+
 def path_expand(text):
     """ returns a string with expanded variable.
 
@@ -316,6 +328,7 @@ def banner(txt=None, c="-", prefix="#", debug=True, label=None,
     Console.cprint(color, "", output)
 
 
+
 # noinspection PyPep8Naming
 def HEADING(txt=None, c="#", color="HEADER"):
     """
@@ -339,6 +352,17 @@ def HEADING(txt=None, c="#", color="HEADER"):
     print()
     banner(msg, c=c, color=color)
 
+# noinspection PyPep8Naming
+def FUNCTIONNAME():
+    """
+    Returns the anme of a function.
+    """
+    frame = inspect.getouterframes(inspect.currentframe())
+
+    filename = frame[1][1].replace(os.getcwd(), "")
+    line = frame[1][2] - 1
+    method = frame[1][3]
+    return method
 
 def backup_name(filename):
     """
@@ -524,3 +548,46 @@ def generate_password(length=8, lower=True, upper=True, number=True):
         else:
             mypw = mypw + _random_character(alphabet)
     return mypw
+
+
+def str_bool(value):
+    return str(value).lower() in ['yes', '1', 'y', 'true', 't']
+
+
+def get_password(prompt):
+    from cloudmesh.common.systeminfo import os_is_windows
+    try:
+        if os_is_windows() and is_gitbash():
+            continuing = True
+            while continuing:
+
+                sys.stdout.write(prompt)
+                sys.stdout.flush()
+                subprocess.check_call(["stty", "-echo"])
+                password = input()
+                subprocess.check_call(["stty", "echo"])
+                sys.stdout.write('Please retype the password:\n')
+                sys.stdout.flush()
+                subprocess.check_call(["stty", "-echo"])
+                password2 = input()
+                subprocess.check_call(["stty", "echo"])
+                if password == password2:
+                    continuing = False
+                else:
+                    Console.error('Passwords do not match\n')
+            return password
+        else:
+            continuing = True
+            while continuing:
+                password = getpass(prompt)
+                password2 = getpass('Please retype the password:\n')
+                if password == password2:
+                    continuing = False
+                else:
+                    Console.error('Passwords do not match\n')
+            return password
+    except KeyboardInterrupt:
+        #Console.error('Detected Ctrl + C. Quitting...')
+        if is_gitbash():
+            subprocess.check_call(["stty", "echo"])
+        raise ValueError('Detected Ctrl + C. Quitting...')
